'use strict';

// Ionic Starter App
angular.module('thinklive', [
    'ionic',

    // ng-cordova
    'ngCordova',

    // angular material
    'ngMaterial',
    'ngMessages',
    'ngAria',
    'ngAnimate',


    // factories
    'thinklive.factories.utilsFactory',
    'thinklive.factories.storageFactory',
    'thinklive.factories.userFactory',

    // services
    'thinklive.services.httpService',
    'thinklive.services.authInterceptor',

    // controllers
    'thinklive.controllers.signInController',
    'thinklive.controllers.signUpController',
    'thinklive.controllers.homeController',
    'thinklive.controllers.sideMenuController',
    'thinklive.controllers.speakersController',
    'thinklive.controllers.networkingController',
    'thinklive.controllers.sponsorController',
    'thinklive.controllers.notificationController',
    'thinklive.controllers.contactUsController',
    'thinklive.controllers.questionController',
    'thinklive.controllers.feedbackController',
    'thinklive.controllers.displayprofileController',
    'thinklive.controllers.changePasswordController',
    'thinklive.controllers.editProfileController',
    'thinklive.controllers.agendaController',
    'thinklive.controllers.eventListController',


    // config
    'thinklive.config'

])

.run(function($configApp, $storage, $httpService, $utils, $user, $ionicPlatform, $rootScope, $ionicHistory, $mdSidenav, $mdDialog, $state, $timeout) {
  $ionicPlatform.ready(function() {
    if(window.cordova && window.cordova.plugins.Keyboard) {
      // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
      // for form inputs)
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);

      // Don't remove this line unless you know what you are doing. It stops the viewport
      // from snapping when text inputs are focused. Ionic handles this internally for
      // a much nicer keyboard experience.
      cordova.plugins.Keyboard.disableScroll(false);
    }

    if(window.StatusBar) {
      StatusBar.styleDefault();
    }

    // data and functions shared among controllers.
    $rootScope.rdata = {};
    $rootScope.rfn = {};

    // if user is signed then set auth token
    if($user.isSignedIn) {
        // set stored auth token
        $httpService.setAuthToken($user.authToken);

        // get user data
        $httpService.userDetails()
        .then(function(success) {
            $user.extend(success.data);
            $user.save();
        }, function(error) {})
        .then(function() {
            $timeout(function() {
                if (navigator.splashscreen)
                    navigator.splashscreen.hide();
            }, 500);

            $rootScope.$broadcast('user-fetched');
        });

    } else {
        $timeout(function() {
            if (navigator.splashscreen)
                navigator.splashscreen.hide();
        }, 200);

        $rootScope.$broadcast('user-fetched');
    }


    PushNotification.hasPermission(function(data) {

        if (data.isEnabled) {
            var push = PushNotification.init({
                android: {
                    senderID: $configApp.data.pushSenderId,
                    sound: true,
                    vibrate: true,
                    forceShow: true,
                    clearNotifications: false,
                }
            });

            push.on('registration', function(data){

                if(data.registrationId) {
                    // $user.pushRegistrationId = data.registrationId;
                    $storage.setData('pushRegistration', data.registrationId);
                    $user.save();
                }

                if($storage.checkData('pushRegistration')){
                    var pushRegistrationId = $storage.getData('pushRegistration');
                }

                if ($user.isSignedIn && pushRegistrationId) {
                    // register device
                    $httpService.registerDevice(pushRegistrationId, $configApp.data.isDiviceAndroid)
                    .then(function(success) {}, function(error) {});
                }
            });


            push.on('notification', function(data) {
                if($state.current.name=="side-menu.home" || $state.current.name=="side-menu.networking") {
                    $rootScope.$broadcast('push-received');
                }
            });
        }
    });

    $ionicPlatform.registerBackButtonAction(function(event) {
        if(angular.element(document).find('md-dialog').length > 0) {
            $mdDialog.hide();
        } else if ($user.isSignedIn && $mdSidenav('left', true).isOpen()) {
            $mdSidenav('left', true).close();
        } else if($state.current.name=="side-menu.eventList") {
            navigator.app.exitApp();
        } else {
            window.history.back();
        }
    }, 100);


  });
});
