'use strict';

angular.module('thinklive.config', [])

/***************************************************
* Routing for Thinklive
***************************************************/
.config(function($stateProvider, $urlRouterProvider) {
    $stateProvider

    // sign in page
    .state('sign-in', {
        url: '/sign-in',
        templateUrl: 'templates/pages/sign-in.html',
        controller: 'signInController',
    })

    // sign up page
    .state('sign-up', {
        url: '/sign-up',
        templateUrl: 'templates/pages/sign-up.html',
        controller: 'signUpController',
    })


    // side-menu and it's child
    .state('side-menu', {
        url: '/side-menu',
        abstract: true,
        templateUrl: 'templates/pages/side-menu.html',
        controller: 'sideMenuController'
    }).state('side-menu.eventList', {
        url: '/event-list',
        templateUrl: 'templates/pages/event-list.html',
        controller: 'eventListController'
    }).state('side-menu.home', {
        url: '/home',
        templateUrl: 'templates/pages/home.html',
        controller: 'homeController'
    }).state('side-menu.speaker', {
        url: '/speaker',
        templateUrl: 'templates/pages/speaker.html',
        controller: 'speakersController'
    }).state('side-menu.networking', {
        url: '/networking',
        templateUrl: 'templates/pages/networking.html',
        controller: 'networkingController'
    }).state('side-menu.sponsor', {
        url: '/sponsor',
        templateUrl: 'templates/pages/sponsor.html',
        controller: 'sponsorController'
    }).state('side-menu.notification', {
        url: '/notification',
        templateUrl: 'templates/pages/notification.html',
        controller: 'notificationController'
    }).state('side-menu.contactUs', {
        url: '/contact-us',
        templateUrl: 'templates/pages/contact-us.html',
        controller: 'contactUsController'
    }).state('side-menu.question', {
        url: '/question',
        templateUrl: 'templates/pages/question.html',
        controller: 'questionController'
    }).state('side-menu.feedback', {
        url: '/feedback',
        templateUrl: 'templates/pages/feedback.html',
        controller: 'feedbackController'
    }).state('side-menu.displayProfile', {
        url: '/display-profile',
        templateUrl: 'templates/pages/display-profile.html',
        controller: 'displayProfileController'
    }).state('side-menu.change-password', {
        url: '/change-password',
        templateUrl: 'templates/pages/change-password.html',
        controller: 'changePasswordController'
    }).state('side-menu.edit-profile', {
        url: '/edit-profile',
        templateUrl: 'templates/pages/edit-profile.html',
        controller: 'editProfileController'
    }).state('side-menu.agenda', {
        url: '/agenda',
        templateUrl: 'templates/pages/ajenda.html',
        controller: 'agendaController'
    })



    /***************************************************
    * Default route.
    * use this route as fall-back if none of the above
    * is not matched.
    ***************************************************/
    $urlRouterProvider.when('', function($utils, $state, $rootScope) {
        $rootScope.$on('user-fetched', function() {
            $state.go($utils.whereToGo());
        });
    });
})


/********************************************************************
* Configure theme and colours for project here.
* Primary palette: Blue(default: 800 or #1565c0)
* Secondary palette: Red(default: 500 or #f44336)
* warning palette: deep orange(default: A700 or #dd2c00)
*
* for more material colors visit:
* https://material.google.com/style/color.html#color-color-palette
*
* To learn more
* https://material.angularjs.org/latest/Theming/03_configuring_a_theme
*********************************************************************/

.config(function($mdThemingProvider) {
    $mdThemingProvider.theme('default')
    .backgroundPalette('grey')
    .primaryPalette('blue', {
        'default': '800',
    })
    .accentPalette('grey', {
        'default': '400',
    });

})


/*************************************************************
* Change these settings to change the behaviour of app.
*************************************************************/
.service('$configApp', function($ionicPlatform) {

    // config data
    var $data = {};

    $ionicPlatform.ready(function() {
        $data.device = ionic.Platform.device();
        $data.isDiviceAndroid = ($data.device.platform == 'Android');
    });

    $data.pushSenderId = '311277465608';

    // files
    var $files = {
        'passwordVisibilityOnIcon': 'img/icons/blue/ic_visibility_24px.svg',
        'passwordVisibilityOffIcon': 'img/icons/blue/ic_visibility_off_24px.svg',
    };

    // compiling data
    var $config = {
        'data': $data,
        'files': $files,
    };


    return $config;
})


.config(['$httpProvider', function($httpProvider) {
    $httpProvider.interceptors.push('$authInterceptor');
}])
