'use strict';

angular.module('thinklive.controllers.editProfileController', [])

.controller('editProfileController', function($configApp, $user, $httpService, $mdDialog, $storage, $window, $utils, $ionicPlatform, $scope, $state, $rootScope) {
    $ionicPlatform.ready(function() {

        /* variables */

        var $data = {}; // local data
        var $fn = {}; // local functions

        $scope.data = {}; // scope data
        $scope.fn = {}; // scope functions
        $scope.data.updateProfileObject = {};
        $scope.errors = {}; // server errors
        $scope.behaviour = {};

        $scope.fn.cancel = function() {
            $state.go('side-menu.displayProfile');
        }

        $scope.fn.home = function() {
            $state.go('side-menu.home');
        }

        $scope.fn.emailBtnDisabled = function(email) {
            if($scope.data.updateProfileObject.email != email) {
                $scope.data.emailDisabledVerified = true;
                $scope.data.emailVerifiyed = true;
                $scope.data.emailDisabledVerify = false;
            }
            else {
                $scope.data.emailVerifiyed = false;
                $scope.data.emailDisabledVerify = true;
            }
        }

        // select a image file
        $scope.fn.selectFile = function() {
            $utils.imagePicker(400, 0)
            .then(function(success) {
                $scope.data.userData.image_url = success.data;
                $scope.data.updateProfileObject.image = success.data;
            }, function(error) {});
        };

        $fn.setDefaults = function() {

            $scope.data.userData = JSON.parse($storage.getData('user'));

            console.log("user data "+JSON.stringify($scope.data.userData));

            // set ng-hide value email verified button

            $scope.data.emailDisabledVerified = true;
            $scope.data.emailDisabledVerify = true;

            // set user data in Input filed;
            $scope.data.updateProfileObject.first_name = $scope.data.userData.first_name;
            $scope.data.updateProfileObject.last_name = $scope.data.userData.last_name;
            $scope.data.updateProfileObject.company = $scope.data.userData.company;
            $scope.data.updateProfileObject.designation = $scope.data.userData.designation;
            $scope.data.updateProfileObject.email = $scope.data.userData.email;
            // $scope.data.updateProfileObject.image_url = $scope.data.userData.image_url;

            if($scope.data.userData.is_email_verified == true)
                $scope.data.emailDisabled = true;
            else
                $scope.data.emailDisabled = false;

            var email = $scope.data.updateProfileObject.email;

            document.addEventListener('change', function (){
                $scope.fn.emailBtnDisabled(email);
                $scope.data.formSaveDisabled = false;
            });

        }();

        // email verification
        $scope.fn.emailVarification = function(email) {
            if(!email)
                return

            $utils.showLoader();
            $httpService.emailVerification(email)
            .then(function(success) {
                $utils.alert("Verification", "A verification Email has been sent to your mail.");
                console.log("success "+JSON.stringify(success));
            }, function(error) {
                console.log("error "+JSON.stringify(error));
                if(error.data.hasOwnProperty('detail')) {
                    $scope.errors.email = error.data.detail;
                    $scope.updateProfileForm['email'].$setValidity('server', false);
                }
            })
            .then(function() {
                $utils.hideLoader();
            });
        };


        // update profile api
        $scope.fn.updateProfileDetails = function(data) {

            if($user.email != $scope.data.updateProfileObject.email) {
                // $scope.data.updateProfileObject.is_email_verified = false;
            }

            $utils.showLoader();

            $httpService.updateProfile(data)
            .then(function(success) {
                console.log("update profile "+JSON.stringify(success));
                $user.extend(success.data);
                $utils.alert("Success", "Your profile has been successfully updated");
                $user.save();
                $state.go('side-menu.displayProfile');
            }, function(error) {
                console.log("error "+JSON.stringify(error));
                angular.forEach(error.data, function(value, key) {
                    if(key != 'detail') {
                        $scope.errors[key] = value[0];
                        $scope.updateProfileForm[key].$setValidity('server', false);
                    } else {
                        $scope.errors.error = value;
                    }
                });
            })
            .then(function() {
                $utils.hideLoader();
            });
        };

    });
})