'use strict';

angular.module('thinklive.controllers.signInController', [])

.controller('signInController', function($user, $httpService, $utils, $storage, $ionicPlatform, $scope, $state, $ionicHistory, $rootScope, $mdDialog, $configApp) {
    $ionicPlatform.ready(function() {

        /* variables */

        var $data = {}; // local data
        var $fn = {}; // local functions

        $scope.data = {}; // scope data
        $scope.errors = {};
        $scope.fn = {}; // scope functions

        $scope.data.loginData = {};

        $scope.fn.signUp = function() {
            $state.go('sign-up');
        }


        $fn.postSignIn = function(data) {
            // set auth token as default in all http request
            var token = data.token;
            delete data.token;

            $httpService.setAuthToken(token);

            // saving data
            $user.extend(data);
            $user.isSignedIn = true;
            $user.authToken = token;
            $user.save();
        };


        /************************************
        * Signs in user in app.
        ************************************/
        $scope.fn.signIn = function(data) {
            $utils.showLoader();

            $httpService.signInUser(data)
            .then(function(success) {
                console.log("success "+JSON.stringify(success));
                // post sign-in
                $fn.postSignIn(success.data);

                $scope.signinForm.$rollbackViewValue();
                $scope.signinForm.$setPristine();
                $scope.signinForm.$setUntouched();
                $state.go($utils.whereToGo());

                if($storage.checkData('pushRegistration')){
                    var pushRegistrationId = $storage.getData('pushRegistration');
                }

                if ($user.isSignedIn && pushRegistrationId) {
                    // register device
                    $httpService.registerDevice(pushRegistrationId, $configApp.data.isDiviceAndroid)
                    .then(function(success) {}, function(error) {});
                }

            }, function(error) {
                console.log("error "+JSON.stringify(error));
                angular.forEach(error.data, function(value, key) {
                    if(key == 'detail') {
                        $scope.errors.error = value;
                    } else {
                    }
                });
            })
            .then(function() {
                $utils.hideLoader();
            });
        };


        $scope.fn.forgotPassword = function() {
            $mdDialog.show({
                templateUrl: 'templates/popups/forgot-password.html',
                clickOutsideToClose: true,
                fullscreen: false,
                parent: angular.element(document.body),
                controller: function($scope, $utils, $user, $mdDialog, $httpService) {
                    $scope.errors = {};
                    $scope.data = {};

                    // close the model
                    $scope.cancel = function() {
                        $mdDialog.cancel();
                    };

                    $scope.email = function(data) {
                        $httpService.forgotPassword(data)
                        .then(function(success) {
                            console.log("success "+JSON.stringify(success));
                            $utils.alert('Sent','A link has been sent to your registered Email ID.');
                            $mdDialog.cancel();
                        }, function(error) {
                            console.log("error "+JSON.stringify(error));
                            angular.forEach(error.data, function(value, key) {
                                if(key != 'detail') {
                                    $scope.errors[key] = value[0];
                                    $scope.askMobile[key].$setValidity('server', false);
                                } else {
                                    $scope.errors.error = value;
                                }
                            });

                        })
                        .then(function() {
                            $utils.hideLoader();
                        });
                    }

                },
            });
        };


        $fn.setDefaults = function() {}();

    });

})