'use strict';

angular.module('thinklive.controllers.signUpController', [])

.controller('signUpController', function($user, $httpService, $utils, $storage, $ionicPlatform, $scope, $state, $ionicHistory, $rootScope, $configApp) {
    $ionicPlatform.ready(function() {

        /* variables */

        var $data = {}; // local data
        var $fn = {}; // local functions

        $scope.data = {}; // scope data
        $scope.errors = {}; // server errors
        $scope.fn = {}; // scope functions

        $scope.data.signUpData = {};

        $data.buttomCheck = true;

        $fn.postSignUp = function(data) {
            // set auth token as default in all http request
            var token = data.token;
            delete data.token;

            $httpService.setAuthToken(token);

            // saving data
            $user.extend(data);
            $user.isSignedIn = true;
            $user.authToken = token;
            $user.save();
        };

        // select a image file
        $scope.fn.selectFile = function() {

            if($scope.data.continueButton)
                return

            $utils.imagePicker(400, 0)
            .then(function(success) {
                $scope.data.signUpData.image = success.data;
            }, function(error) {});
        };


        $scope.fn.signUp = function(data) {
            $utils.showLoader();

            // register user
            $httpService.registerUser(data)
            .then(function(success) {
                console.log("success "+JSON.stringify(success));
                $utils.alert("Verify Email", "Please verify your E-mail");

                $user.is_email_verified = false;
                $scope.data.creatAccountButton = false;
                $scope.data.continueButton = true;
                $scope.data.resentButton = true;
                $scope.data.readonlyCheck = true;
                // post sign-up
                $fn.postSignUp(success.data);

            }, function(error) {
                console.log("error "+JSON.stringify(error))
                angular.forEach(error.data, function(value, key) {
                    if(key != 'detail') {
                        $scope.errors[key] = value[0];
                        $scope.signUpForm[key].$setValidity('server', false);
                    } else {
                        $scope.errors.error = value;
                    }
                });
            })
            .then(function() {
                $utils.hideLoader();
            });
        };


        $scope.fn.signIn = function() {
            $state.go('sign-in');
        }

        $scope.fn.continue = function() {
            $utils.showLoader();

            // register user
            $httpService.emailVerificationstatus()
            .then(function(success) {
                console.log("success continue "+JSON.stringify(success));
                $user.is_email_verified = true;
                $user.save();
                // reset form
                $scope.data.signUpData = {};
                $scope.signUpForm.$rollbackViewValue();
                $scope.signUpForm.$setPristine();
                $scope.signUpForm.$setUntouched();

                if($storage.checkData('pushRegistration')){
                    var pushRegistrationId = $storage.getData('pushRegistration');
                }

                if ($user.isSignedIn && pushRegistrationId) {
                    // register device
                    $httpService.registerDevice(pushRegistrationId, $configApp.data.isDiviceAndroid)
                    .then(function(success) {}, function(error) {});
                }

                $state.go('side-menu.home');

            }, function(error) {
                console.log("error "+JSON.stringify(error))
                angular.forEach(error.data, function(value, key) {
                    if(key == 'detail') {
                        $scope.errors.error = value;
                    }
                });
            })
            .then(function() {
                $utils.hideLoader();
            });
        }

        $scope.fn.resentEmail = function() {
            var data = {
                'change_email' : '',
            };

            $httpService.resentEmail(data)
            .then(function(success) {
                $scope.errors.error = '';
                console.log("success "+JSON.stringify(success));
                $utils.alert('Verification Mail send.');

            }, function(error) {
                console.log("error "+JSON.stringify(error))
                angular.forEach(error.data, function(value, key) {
                    if(key == 'detail') {
                        $scope.errors.error = value;
                    }
                });
            })
            .then(function() {
                $utils.hideLoader();
            });

        }


        $fn.setDefaults = function() {

            $scope.data.creatAccountButton = false;
            $scope.data.continueButton = false;
            $scope.data.resentButton = false;

            if($user.is_email_verified == false) {
                $scope.data.userData = JSON.parse($storage.getData('user'));
                console.log("user data "+JSON.stringify($scope.data.userData));
                $data.buttomCheck = true;
                $scope.data.readonlyCheck = true;
                // set user data to input fields
                $scope.data.signUpData.full_name = $scope.data.userData.full_name;
                $scope.data.signUpData.designation = $scope.data.userData.designation;
                $scope.data.signUpData.company = $scope.data.userData.company;
                $scope.data.signUpData.email = $scope.data.userData.email;
            } else {
                $data.buttomCheck = false;
                $scope.data.readonlyCheck = false;
            }


            if($data.buttomCheck) {
                $scope.data.continueButton = true;
                $scope.data.resentButton = true;
            }
            else{
                $scope.data.creatAccountButton = true;
            }
        }();

    });

})