'use strict';

// factory to manage persistence storage

angular.module('thinklive.factories.storageFactory', [])

.factory('$storage', function($window){
    /**********************************************************
    * Object containing all the function this factory have.
    * These values are being stored as String in $storage.
    * convert back objects by passing them into JSON.parse().
    **********************************************************/
    var $fn = {};

    var hasTourVisted = false;

    /**************************************
    * Functions to handle persistent data
    * Using html 5 localStorage api
    **************************************/

    // get data from storage
    $fn.getData = function(key) {
        return $window.localStorage[key];
    };

    // set data in storage
    $fn.setData = function(key, value) {
        $window.localStorage[key] = value;
    };

    // check data in storage
    $fn.checkData = function(key) {
        return $window.localStorage.hasOwnProperty(key);
    };

    // delete data from storage
    $fn.deleteData = function(key) {
        delete $window.localStorage[key];
    };

    // clear local storage data
    $fn.clearData = function() {
        window.localStorage.clear();
    }

    /**************************************
    * Functions to handle temporary data
    * Using html 5 sessionStorage api
    **************************************/

    // get data from storage
    $fn.getTempData = function(key) {
        return $window.sessionStorage[key];
    };

    // set data in storage
    $fn.setTempData = function(key, value) {
        $window.sessionStorage[key] = value;
    };

    // check data in storage
    $fn.checkTempData = function(key) {
        return $window.sessionStorage.hasOwnProperty(key);
    };

    // delete data from storage
    $fn.deleteTempData = function(key) {
        delete $window.sessionStorage[key];
    };


    return $fn;
});