'use strict';

// contains user factory

angular.module('thinklive.factories.userFactory', [])

.factory('$user', function($storage) {
    // everything user has
    var user = {};
    user.temp = {}; // temporary data user may have
    // data
    user.isSignedIn = false;
    user.authToken = undefined;

    // functions

    // set bulk data on user if from object
    user.extend = function(userData) {
        for(var each in userData)
            user[each] = userData[each];
    };

    // set bulk data on user if from object
    user.extendTemp = function(userData) {
        for(var each in userData)
            user.temp[each] = userData[each];
    };

    // save data to storage
    user.save = function() {
        var dataToSave = {};

        for(var each in user) {
            // collect all the non function members
            if(typeof(user[each]) !== 'function' && each !== 'temp')
                dataToSave[each] = user[each];
        }

        $storage.setData('user', JSON.stringify(dataToSave));
    };

    // display all the user data
    user.showAllCards = function() {
        var cards = {};
        for(var each in user) {
            // collect all the non function members
            if(typeof(user[each]) !== 'function')
                cards[each] = user[each];
        }

        console.log(JSON.stringify(cards));
    };

    // delete user data
    user.destroy = function() {
        $storage.deleteData('user');

        for(var each in user) {
            // collect all the non function members
            if(typeof(user[each]) !== 'function')
                delete user[each];
        }

        user.isSignedIn = false;
        user.authToken = undefined;
        user.temp = {};
    };

    // clear temp data
    user.clearTempData = function() {
        user.temp = {};
    };

    // restore user data
    (function(){
        // get user data from storage
        var userData = $storage.checkData('user')?JSON.parse($storage.getData('user')):{};
        for(var each in userData)
            user[each] = userData[each];
    }());

    return user;
});