'use strict';

// contains helpers functions

angular.module('thinklive.factories.utilsFactory', [])

.factory('$utils', function($user, $storage, $rootScope, $ionicLoading, $mdDialog, $q, $state, $cordovaImagePicker, $cordovaFile, $configApp) {
    /**********************************************************
    * object containing all the function this factory have.
    *********************************************************/
    var $fn = {};

    // function to show loader
    $fn.showLoader = function() {
        $ionicLoading.show({
            template: '<div layout="column" layout-align="center center" class="thinklive-loader"><md-progress-circular md-mode="indeterminate" md-diameter="60"></md-progress-circular></div>',
        });
    };

    // function to hide loader
    $fn.hideLoader = function() {
        $ionicLoading.hide();
    };

    // function to show an alert with given title and message
    $fn.alert = function(title, message) {
        $mdDialog.show(
            $mdDialog.alert()
            .clickOutsideToClose(true)
            .title(title)
            .textContent(message)
            .ariaLabel(title)
            .ok('OK')
        );
    };

    // shows a confirm dialogue to given title and message
    $fn.confirm = function(title, message) {
        var confirm = $mdDialog.confirm()
          .title(title)
          .textContent(message)
          .ariaLabel(title)
          .ok('Yes')
          .cancel('No');

        return $mdDialog.show(confirm);
    };

    // tell where to go
    $fn.whereToGo = function() {
        if($user.isSignedIn && $user.is_email_verified) {
            return 'side-menu.eventList';
        } else {
            return 'sign-in';
        }
    };

    // ask permission from user
    // this function is only meant to be called after device ready event.
    // docs: https://github.com/dpa99c/cordova-diagnostic-plugin
    // permitions: https://github.com/dpa99c/cordova-diagnostic-plugin#dangerous-runtime-permissions
    $fn.requestPermission = function(permissionFor) {
        var promise = $q.defer();

       if($configApp.data.device.platform != 'Android') {
            promise.resolve(true);
        } else {

            cordova.plugins.diagnostic.requestRuntimePermission(function(status){
                switch(status){
                    case cordova.plugins.diagnostic.permissionStatus.GRANTED:
                        promise.resolve(true);
                        break;
                    case cordova.plugins.diagnostic.permissionStatus.NOT_REQUESTED:
                        promise.reject(false);
                        break;
                    case cordova.plugins.diagnostic.permissionStatus.DENIED:
                        $fn.alert('Error', 'Permission was Denied.');
                        promise.reject(false);
                        break;
                    case cordova.plugins.diagnostic.permissionStatus.DENIED_ALWAYS:
                        $fn.alert('Error', 'Permission was permanently Denied. Please change your app settings to access.');
                        promise.reject(false);
                        break;
                }
            }, function(error){
                console.error("The following error occurred: "+JSON.stringify(error));
            }, permissionFor);

        }

        return promise.promise;
    };

    // image picker
    // this function is only meant to be called after device ready event.
    $fn.imagePicker = function(width=0, height=0) {
        var promise = $q.defer();

        var permission = '';

        if($configApp.data.device.platform == 'Android')
            permission = cordova.plugins.diagnostic.permission.READ_EXTERNAL_STORAGE;
        else
            permission = null;

        $fn.requestPermission(permission)
        .then(function(success) {
            $cordovaImagePicker.getPictures({
                maximumImagesCount: 1,
                width: width,
                height: height,
                quality: 100,
            })
            .then(function(results) {
                console.log("result "+results[0]);
                if(results[0]) {
                    $cordovaFile.readAsDataURL(cordova.file.cacheDirectory, results[0].split('com.finnovationlive.thinklive/cache/')[1])
                    .then(function(success){
                        promise.resolve({'path': results[0], 'data':success});
                    }, function(error) {
                        $fn.alert('Error', 'Unable to read image');
                        promise.reject(false);
                    });
                } else {
                    promise.reject(false);
                }
            }, function(error) {
                $fn.alert('Error', 'Unable open image picker');
                promise.reject(false);
            });
        }, function(error) {
            promise.reject(false);
        });

        return promise.promise;
    };


    // email function
    $fn.email = function(email) {
        window.open('mailto:'+email+'', '_system', 'location=yes');
    }


    return $fn;

});
