'use strict';
// service to communicate with thinklive server

angular.module('thinklive.services.httpService', [])

.service('$httpService', function($utils, $http, $state, $window){

    /**********************************************************
    * Api end point prefix.
    * This is the address where app will send all the request.
    * Change this value for
    * development: change 10.42.0.1 with ip address on
                    which your dev server is running
    * production: change 10.42.0.1 with com.finnovationlive.thinklive
    **********************************************************/
    var $host = 'http://thinklive-deploy.ap-south-1.elasticbeanstalk.com/api';


    /**********************************************************
    * object containing all the function this service have.
    *********************************************************/
    var $fn = {};

    // set auth token in authorization requests
    $fn.setAuthToken = function(token) {
        $http.defaults.headers.common.Authorization = 'Token '+token;
    };

    // delete request token
    $fn.deleteAuthToken = function() {
        delete($http.defaults.headers.common.Authorization);
    };

    // if no Internet connection send to InternetNotFound
    $fn.checkInternet = function() {
        if($window.Connection) {
            if(navigator.connection.type == Connection.NONE) {
                $utils.hideLoader();
                $utils.alert('Error', 'You are Offline. Please check your Internet Connection.');
                return false;
            }
        }
        return true;
    };


    // actual http calls

    $fn.hitPostAPI = function(request_url, data, cache=false, isLoginRequired=true) {
        console.log('POST request:: URL: '+request_url+' DATA: '+JSON.stringify(data));
        if ($fn.checkInternet()) {
            if (isLoginRequired && !$http.defaults.headers.common.Authorization) {
                return;
            }
            return $http.post(request_url, data, {cache: cache});
        }
    };

    $fn.hitPutAPI = function(request_url, data, cache=false, isLoginRequired=true) {
        console.log('PUT request:: URL: '+request_url+' DATA: '+JSON.stringify(data));
        if ($fn.checkInternet()) {
            if (isLoginRequired && !$http.defaults.headers.common.Authorization) {
                return;
            }
            return $http.put(request_url, data, {cache: cache});
        }
    };

    $fn.hitPatchAPI = function(request_url, data, cache=false, isLoginRequired=true) {
        console.log('PATCH request:: URL: '+request_url+' DATA: '+JSON.stringify(data));
        if ($fn.checkInternet()) {
            if (isLoginRequired && !$http.defaults.headers.common.Authorization) {
                return;
            }
            return $http.patch(request_url, data, {cache: cache});
        }
    };

    $fn.hitGetAPI = function(request_url, cache=false, isLoginRequired=true, isInternetRequired=true) {
        console.log('GET request:: URL: '+request_url);
        if (isInternetRequired && $fn.checkInternet()) {
            if (isLoginRequired && !$http.defaults.headers.common.Authorization) {
                return;
            }
            return $http.get(request_url, {cache: cache});
        }
        return $http.get(request_url, {cache: cache});
    };

    $fn.hitDeleteAPI = function(request_url, isLoginRequired=true, isInternetRequired=true) {
        console.log('DELETE request:: URL: '+request_url);
        if (isInternetRequired && $fn.checkInternet()) {
            if (isLoginRequired && !$http.defaults.headers.common.Authorization) {
                return;
            }
            return $http.delete(request_url);
        }
        return $http.delete(request_url);
    };


    // register user
    $fn.registerUser = function(data) {
        var url = $host+'/v1/create-user.json';
        return $fn.hitPostAPI(url, data, false, false);
    };


    $fn.registerDevice = function(reg_id, is_android) {
        var url = $host+'/v1/register-device.json';

        var data = {
            'reg_id': reg_id,
            'is_android': is_android,
        }

        return $fn.hitPostAPI(url, data, false, true);
    };

    $fn.unRegisterDevice = function() {
        var url = $host+'/v1/unregister-device.json';

        return $fn.hitGetAPI(url, false, true);
    };

    // sign in user
    $fn.signInUser = function(data) {
        var url = $host+'/v1/login.json';
        return $fn.hitPostAPI(url, data, false, false);
    }

    // email verificatiojn status
    $fn.emailVerificationstatus = function() {
        var url = $host+'/v1/is-email-verified.json';
        return $fn.hitGetAPI(url, false, true, true);
    }

    // resent email
    $fn.resentEmail = function(data) {
        var url = $host+'/v1/send-email-verification-mail.json';
        return $fn.hitPostAPI(url, data, false, true);
    };

    // user active event api
    $fn.eventList = function() {
        var url = $host+'/v1/active-event-list.json';
        return $fn.hitGetAPI(url, false, true, true);
    }

    // user active event api
    $fn.eventDetails = function(eventId) {
        var url = $host+'/v1/user-active-event/'+eventId+'.json';
        return $fn.hitGetAPI(url, false, true, true);
    }

    // user data api
    $fn.userDetails = function() {
        var url = $host+'/v1/user.json';
        return $fn.hitGetAPI(url, false, true, true);
    }

    // speaker data api
    $fn.speakerData = function(id) {
        var url = $host+'/v1/event/'+id+'/speaker-list.json';
        return $fn.hitGetAPI(url, false, true, true);
    }

    // networking data api
    $fn.networkingData = function(id) {
        var url = $host+'/v1/event/'+id+'/network-detail.json';
        return $fn.hitGetAPI(url, false, true, true);
    }

    $fn.requestEmail = function(eventId, userId, requestUserId) {
        var data = {
            'event' : eventId,
            'from_user' : userId,
            'to_user' : requestUserId,
            'status' : 'N'
        };

        var url = $host+'/v1/event/'+eventId+'/create-request.json';
        return $fn.hitPostAPI(url, data, false, true);
    };

    // sponsor data api
    $fn.sponsorData = function(id) {
        var url = $host+'/v1/event/'+id+'/sponsor-list.json';
        return $fn.hitGetAPI(url, false, true, true);
    }

    $fn.question = function(data, id) {
        var url = $host+'/v1/event/'+id+'/question.json';
        return $fn.hitPostAPI(url, data, false, true);
    };

    $fn.contact = function(data) {
        var url = $host+'/v1/contact-us.json';
        return $fn.hitPostAPI(url, data, false, true);
    };

    $fn.feedback = function(data, id) {
        var url = $host+'/v1/event/'+id+'/feedback.json';
        return $fn.hitPostAPI(url, data, false, true);
    };

    $fn.forgotPassword = function(data) {
        var url = $host+'/v1/forgot-password.json';
        return $fn.hitPostAPI(url, data, false, false);
    };

     // password update api
    $fn.updatePassword = function(data) {
        var url = $host+'/v1/change-password.json';
        return $fn.hitPatchAPI(url, data, false, true);
    }

    $fn.updateProfile = function(data) {
        var url = $host+'/v1/update-user.json';
        return $fn.hitPatchAPI(url, data, false, true);
    }

    $fn.emailVerification =  function(email) {
        var data = {
             "change_email": email
        };

        var url = $host+'/v1/send-email-verification-mail.json';
        return $fn.hitPostAPI(url, data, false, true);
    }

    // agenda data api
    $fn.agendaData = function(id) {
        var url = $host+'/v1/event/'+id+'/agenda-list.json';
        return $fn.hitGetAPI(url, false, true, true);
    }

    $fn.requestsEmail = function(id) {
        var url = $host+'/v1/event/'+id+'/request-list.json';
        return $fn.hitGetAPI(url, false, true, true);
    }

    $fn.requestAccpect =  function(eventId, requesterId) {
        var data = {
             "status": 'A'
        };

        var url = $host+'/v1/event/'+eventId+'/update-request/'+requesterId+'.json';
        return $fn.hitPutAPI(url, data, false, true);
    }

    $fn.requestReject =  function(eventId, requesterId) {
        var data = {
             "status": 'R'
        };

        var url = $host+'/v1/event/'+eventId+'/update-request/'+requesterId+'.json';
        return $fn.hitPutAPI(url, data, false, true);
    }

    $fn.notificationCount = function() {
        var url = $host+'/v1/last-seen-alert-check.json';
        return $fn.hitGetAPI(url, false, true, true);
    }

    $fn.notificationAlert = function(id) {
        var url = $host+'/v1/event/'+id+'/alert-list.json';
        return $fn.hitGetAPI(url, false, true, true);
    }

    $fn.expressInterest = function(id) {
       var url = $host+'/v1/event/'+id+'/send-user-intrest.json';
       return $fn.hitGetAPI(url, false, true, true);
    }

    $fn.responseError = function(response) {
        console.log("error");
    };

    return $fn;
})
